# Critique / Models of Good Data Visualization

---
## This Week

- Review common rules & mistakes.
- What makes a useful critique?
- **Look at a lot of examples.**

Like any kind of visual art, creating good visualizations takes *learning to see*.


---

## Reminder: Color

- Appropriate & consistent use of color for data type.
- Contrast & distinguishable palette.
- Cultural/contextual considerations.
- Accessibility: contrast, color vision deficiency, legibility

---

## Reminder: Data / Chart Integrity

- Data variation, not design variation.
- Maximize data-ink ratio.
- Strip out chart junk. (gridlines, shadows, 3d effects)
- Add Context: title, axes, units, important events.
- Alignment/Proximity: make comparisons easy & avoid misleading choices like changing axes between two otherwise identical graphs

---

## What to Look For

**Expressiveness**: Does every choice further the understanding of the data?

**Effectiveness**: Can audience decipher data and meaning quickly? 

**Non-Data Elements**
- Title, Label, Caption, Data Source, Annotations
- Gridlines, Legend
- Appropriate use of grouping/sorting.


---

## Critique

- What is the purpose of critique?
- Constructive Language
- Taking Critique

---

## Purpose of Critique

You are the expert on your data source, and it can be challenging to look at things through the eyes of your audience.

It is likely that you've stared at variations of the same chart for an hour or more, easily overlooking small flaws.

Extra eyes will help you identify what people are actually taking away from your graphic:

- Highlight accessibility issues.
- Preempt confusion/accidentally misleading intended audience.
- Uncover unconscious biases.
- Consider alternative solutions.

---

## Giving Critique

**Be specific.** If your first impulse is "I like it/I don't like it" go deeper and connect with why. Does it violate principles? Does a color choice stress your eye?

**Give your interpretation.** What do you take away from the graphic as-is. Where is your eye drawn? Check your understanding against intention.

**Balance positives and negatives.** Find things that *are working* and incorporate those into feedback as well. It's easier on recipient but also important so that they don't get removed in revision.

**Offer alternatives.** What could be done differently?

---

## Critique Language

**"I like..."** - point out what works.
**"I wish..."** - frame negative feedback as ways that it could improve for audience.
**"What if..."** - new ideas and alternatives to consider.

**Be respectful.** Be mindful of your tone and word choice.

---

## What to Avoid (Giving Critique)

**Comments on creator.** "You always...", "What were you thinking?", etc.  **Stay focused on the work.**

**Bike-shedding.** Suggesting *arbitrary* changes based on your preferences. "If I made this, I'd have chosen green."

![bg right height:200px](bikeshed.png)

<https://bikeshed.org>

---

## Receiving Critique

**Listen without defensiveness.** Do not interrupt initial feedback to defend/clarify your intentions, doing so will lead to missing important first impressions.

**Separate yourself from the work.** Remember the context you are doing this in, your peer is giving you their time to improve your work.

**Ask clarifying questions.** If you do not understand why their interpretation is what it is, ask! Take the opportunity to learn more about what a new viewer will see.

**Look for patterns.** Feedback may be unique or contradictory. Focus on trends in the feedback that point to common issues.

---

## What to Avoid (When Receiving Critique)

**Convincing.** If someone misunderstood your viz, others will too. There's nothing to be gained by convincing them they actually do understand it.

**Assuming all feedback is correct.** If you disagree with a piece of feedback, it is OK to thank the person for it and not incorporate that into your changes if you feel strongly it was off base. There's generally no need to debate them on the spot however.

---

## Suggested Peer Critique Process

1) Share work with no commentary.  Give everyone in the group a chance to form initial opinions.  As a reviewer, jot down a few notes.

2) Author can now provide explanation of audience/intent. Keep this short & avoid explaining specifics of any graphic. I recommend doing this after the initial impression to avoid coloring people's first take. If author has 1-2 specific questions they could be introduced at this time.

3) Start with some positive feedback. What is working well.

---

4) Offer constructive criticisms and other suggestions for improvements and things to try.  Author should mostly listen at this point, take notes, avoid the urge to respond to each piece of feedback as offered.

5) Author can now ask clarifying questions and respond as appropriate.
    - "When you said you didn't understand X, did looking at the next chart help? If I reorder those would it have helped?""
    - "Does anyone have "

6) Consolidate and summarize feedback and next steps.  "OK I think I'll take a pass at a standard scatterplot here since the bubble chart was confusing people."

---

## Practice Critique

---

![bg fit](nightingale-mortality.jpg)

<!--
Crimean War via Livia, <https://edstem.org/us/courses/68015/discussion/5428917>

author: Florence Nightingale

- legend?
- labeling on the chart itself?
-->

---

![bg fit](dubois-hourglass.png)

<!--
DuBois hourglass

He pronounced his name De-bois

not a pie chart! meant for direct comparison between the two types

today this would be misread because people have seen pie charts
-->

---

![bg fit](chicago-segregation.png)

<!-- 
Chicago Racial Segregation via Miguel, <https://edstem.org/us/courses/68015/discussion/5441644>

type: map
-->

---

![bg fit](dubois-slaves.jpg)

<!--
DuBois slaves visualization

-->

---

![bg fit](eye-colors.webp)

<!--
eye color

uncertainity
why are some slices larger than others?
does the eye in the middle mislead?
-->

---

![bg fit](lee-1pct.png)
<!-- 
1% of 1% via <https://sunlightfoundation.com/2013/06/26/1pct_of_the_1pct_polarization/>
-->


---

![bg fit](grammys.png)

<!-- Grammys via Ruben, <https://edstem.org/us/courses/68015/discussion/5452397> -->

---

![bg fit](leo.png)

<!-- DiCaprio via Amber -->

---

![bg fit](nc-538.png)

<!-- Will's NC Seats via <https://projects.fivethirtyeight.com/partisan-gerrymandering-north-carolina/>  -->

---

![bg fit](kfc.png)

<!-- KFC from Minh -->

---

![bg fit](immigration.jpeg)
<!-- hungarian immigration from Dorka -->

---

![bg fit](military.png)
<!-- military from Tori -->

---

![bg fit](military2.png)
<!-- part 2 of military expenditure -->

---

![bg fit](nz.png)
<!-- NZ -->

---

![bg fit](gender.png)
<!-- gender -->

---

![bg fit](ny-radial.jpg)
<!-- ny radial -->

---

![bg fit](tx-radial.jpg)
<!-- tx radial -->

---

![bg fit](iraq.jpg)
<!-- iraq -->

---

![bg fit](inequality.jpg)
<!-- inequality by Yi-Huai -->

---

![bg fit](fox-sp500.png)

<!-- Fox from Andrew -->

---

![bg fit](tx.jpg)

<!-- tribes in texas from Echo -->


---

![bg fit](github.png)

<!--

github
two issues: scale is dependent on person's max commits
more importantly: what we choose to visualize has an effect

-->

---

## Readings & Sources

- [Critiquing data visualizations: A discussion on channeling empathy and productivity]( https://www.tableau.com/blog/critiquing-data-visualizations-channel-empathy-and-be-productive)
- <https://policyviz.com/2020/07/19/critiquing-a-data-visualization-critique/>
